@@ -1,5 +1,5 @@
 /* This file is part of the Zebra server.
-   Copyright (C) 2004-2013 Index Data
+   Copyright (C) Index Data
 
 Zebra is free software; you can redistribute it and/or modify it under
 the terms of the GNU General Public License as published by the Free
@@ -86,7 +86,7 @@ int main(int argc, char **argv)
         " drop <db>     Drop database <db>\n"
         " commit        Commit changes\n"
         " clean         Clean shadow files\n"
-        " check:mode    Check register; mode is one of: default, full, quick\n"
+        " check mode    Check register; mode is one of: default, full, quick\n"
         "Options:\n"
 	" -t <type>     Index files as <type> (grs or text).\n"
 	" -c <config>   Read configuration file <config>.\n"
@@ -248,7 +248,7 @@ int main(int argc, char **argv)
             zebra_get_version(version_str, sys_str);
 
             printf("Zebra %s\n", version_str);
-	    printf("(C) 1994-2013, Index Data ApS\n");
+	    printf("(C) 1994-2014, Index Data\n");
             printf("Zebra is free software, covered by the GNU General Public License, and you are\n");
             printf("welcome to change it and/or distribute copies of it under certain conditions.\n");
             printf("SHA1 ID: %s\n", sys_str);
