@@ -1,5 +1,5 @@
 /* This file is part of the Zebra server.
-   Copyright (C) 2004-2013 Index Data
+   Copyright (C) Index Data
 
 Zebra is free software; you can redistribute it and/or modify it under
 the terms of the GNU General Public License as published by the Free
@@ -29,7 +29,6 @@ static RSFD r_open (RSET ct, int flag);
 static void r_close (RSFD rfd);
 static void r_delete (RSET ct);
 static int r_read (RSFD rfd, void *buf, TERMID *term);
-static int r_write (RSFD rfd, const void *buf);
 static void r_pos (RSFD rfd, double *current, double *total);
 
 static const struct rset_control control =
@@ -42,7 +41,7 @@ static const struct rset_control control =
     0, /* no forward */
     r_pos,
     r_read,
-    r_write,
+    rset_no_write,
 };
 
 struct rfd_private {
@@ -113,12 +112,6 @@ static int r_read (RSFD rfd, void *buf, TERMID *term)
     return rc;
 }
 
-static int r_write (RSFD rfd, const void *buf)
-{
-    yaz_log (YLOG_FATAL, "ISAMS set type is read-only");
-    return -1;
-}
-
 static void r_pos (RSFD rfd, double *current, double *total)
 {
     *current=-1;  /* sorry, not implemented yet */
